@@ -3,7 +3,7 @@ package Import::Export;
 use Carp;
 use namespace::clean ();
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 our %EX;
 
@@ -16,20 +16,24 @@ our %EXTYPE = (
 );
 
 sub import {
-	my ($pkg) = shift;
+	my ($pkg, $options, $caller) = (shift, {}, caller());
 	return unless my @export = @_;
-	my $options = pop @export if ref $export[-1];
-
 	Carp::croak('define your %EX export hash')
 		unless (%EX) = %{"${pkg}::EX"};
 	
-	my $caller = caller();
+	$options = pop @export if ref $export[-1];
+	$caller = $options->{-caller} if exists $options->{-caller};
 	my @exported = export($pkg, $caller, @export);
-	
-	'namespace::clean'->import(
-		-cleanee => $caller,
-		@exported,
-	) if $options->{clean}; 
+
+	$options->{clean} and "$options->{clean}" eq "import"
+		? namespace::clean->clean_subroutines( # sub import { p->import(@export, { clean => 'import' }) }
+			$caller,
+			@exported
+		)
+		: namespace::clean->import(  # use p @export, { clean => 'import' }
+			-cleanee => $caller,
+			@exported
+		);
 }
 
 sub export {
@@ -52,7 +56,7 @@ sub export {
 		*{"${caller}::${ex}"} = $exporting->($pkg, $ex);
 		push @exported, $ex;
 	}
-	return @expoted;
+	return @exported;
 }
 
 sub _export_code { \&{"$_[0]::$_[1]"} }
@@ -71,7 +75,7 @@ Import::Export - Exporting
 
 =head1 VERSION
 
-Version 0.06
+Version 0.07
 
 =cut
 
